﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

using System.Data.Entity;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;

namespace InvoiceManagerWeb.Models
{
    /// <summary>
    /// Datová třída reprezentující osobu
    /// </summary>
    public class Person
    {
        /// <value>
        /// ID společnosti, jedná se o ICO
        /// </value>
        [Key] //označí jakoukoli položku jako primární klíč
        public int ID { get; set; }

        /// <value>
        /// Jméno osoby
        /// </value>
        [Display(Name="Jméno")]
        public String Name { get; set; }

        /// <value>
        /// Přijmení osoby
        /// </value>
        [Display(Name = "Přijmení")]
        public String Surname { get; set; }

        /// <value>
        /// Číslo bankovního účtu
        /// </value>
        [Display(Name = "Bankovní účet")]
        public String BankAccount { get; set; }

        /// <value>
        /// DIC - Danove identifikacni cislo, je-li vyplneno jedna se o platce DPH
        /// </value>
        [Display(Name = "DIČ")]
        public String TaxId { get; set; }
        
        /// <value>
        /// Ulice
        /// </value>
        [Display(Name = "Ulice")]
        public String Street { get; set; }

        /// <value>
        /// Číslo popisné
        /// </value>
        [Display(Name = "Číslo popisné")]
        public int Nr { get; set; }

        /// <value>
        /// PSČ - Postovni smerovaci cislo
        /// </value>
        [Display(Name = "PSČ")]
        public int PostCode { get; set; }

        /// <summary>
        /// Vrací celé jméno osoby jako jeden string
        /// </summary>
        public string CompleteName
        {
            get
            {
                return Name + " " + Surname;
            }
        }

        public override string ToString()
        {
            return CompleteName;
        }

        /// <summary>
        /// Metoda vytvoří list pro možnost výběru osoby z DropDownListu
        /// </summary>
        public static SelectList createList()
        {
            PersonContext db = new PersonContext();
            List<Person> seznam = new List<Person>();
            seznam.AddRange(db.Persons);

            return new SelectList(seznam, "ID", "CompleteName");
        }
    }

    /// <summary>
    /// Databázový kontext pro osoby
    /// </summary>
    public class PersonContext : DbContext
    {
        public DbSet<Person> Persons { get; set; }

    }
}